#include <cstdio>
#include <cstring>
#include <cmath>

#define EPS 1e-7

using namespace std;

int d, k;
double r;

inline int cmpf(double a, double b) {
    if (fabs(a-b) < EPS) return 0;
    return a < b ? -1 : 1;
}

struct pvec {
    double x, y;
    pvec(double x=0, double y=0) :x(x), y(y) {}
    pvec operator+(pvec p) { return pvec(x+p.x,y+p.y); }
    pvec operator-(pvec p) { return pvec(x-p.x,y-p.y); }
    pvec operator*(double a) { return pvec(a*x,a*y); }
    double dot(pvec p) { return x*p.x + y*p.y; }
    double cross(pvec p) { return x*p.y - y*p.x; } // < 0 se p tá a direita de this
    double abs() { return sqrt(x*x + y*y); }
    double angulo(pvec p) { // angulo entre vetores
                   //[---cos do angulo----]
        return acos( dot(p)/(abs()*p.abs()) );
    }
};


double area_triangulo(pvec p1, pvec p2, pvec p3) {
    return fabs( (p2-p1).cross(p3-p1) )/2.0;
}

struct reta {
    pvec P, vd;
    reta(pvec A, pvec B) :P(A), vd(B-A) {} // Definir reta dados dois pontos!!
};

struct circ {
    pvec c;
    double r;
    circ(pvec c=pvec(0,0), double r=0) :c(c), r(r) {} //dado ponto e raio
    bool intersec_reta(reta s, pvec &p1, pvec &p2) {
        double H=s.P.x - c.x;
        double I=s.P.y - c.y;
        double A = s.vd.x*s.vd.x + s.vd.y*s.vd.y;
        double B = 2.0*(s.vd.x*H + s.vd.y*I);
        double C = H*H + I*I - r*r;
        double D = B*B - 4.0*A*C;
        if (cmpf(D,0.0) < 0) return false;
        double L1 = (-B+sqrt(D))/(2.0*A);
        double L2 = (-B-sqrt(D))/(2.0*A);
        p1 = s.vd*L1 + s.P;
        p2 = s.vd*L2 + s.P;
        return true;
    }
};


double area(double x) {
    if (cmpf(x,r)==0) {
        return (M_PI*r*r)/2.0;
    }
    if (x < r) {
        reta R = reta(pvec(x,0), pvec(x,50.0));
        circ c = circ(pvec(r,0), r);
        pvec p1, p2;
        c.intersec_reta(R, p1, p2);
        p1 = p1 - pvec(r,0);
        p2 = p2 - pvec(r,0);
        double ang = p1.angulo(p2);
        double setor = (r*r*ang)/2.0;
        pvec centro = pvec(r,0);
        double tri = area_triangulo(centro, centro+p1, centro+p2);
        return setor-tri;
    }

    // x > r
    return M_PI*r*r - area(d-x);
}

int main() {

    while(scanf("%d %d",&d,&k) and (d or k)) {
        r = (double)d/2.0;
        k--; // qts retas
        double a = M_PI*r*r;
        a = a/(k+1);
        if (!k) { printf("\n"); continue; }
        for (int i=1;i<=k;i++) {
            double qro = a*(double)i;
            double ini = 0.0, fim = d;
            for (int tt=0;tt<128;tt++) {
                double m = (ini+fim)/2.0;
                double tenho = area(m);
                if (tenho > qro)
                    fim = m;
                else
                    ini = m;
            }
            if (i>1) printf(" ");
            printf("%.2lf",ini);
        }
        printf("\n");
    }

    return 0;
}
